..
   This is an autogenerated file from processors.rst

avatars.processors.ExpectedMeanProcessor
========================================

.. autoclass:: avatars.processors.ExpectedMeanProcessor
   :members: